@@ -1,31 +1,27 @@
-import copy, random, json, os, threading, shutil
+import copy
+import json
+import logging
+import os
+import platform
+import random
+import shutil
+import sys
+import threading
 
-from flask import (
-    Flask,
-    Blueprint,
-    render_template,
-    request,
-    redirect,
-    url_for,
-    jsonify,
-    flash,
-)
-from flask_login import login_required, current_user
+from flask import Blueprint
 from flask import current_app as app
-from mnemonic import Mnemonic
-from ..helpers import alias, is_testnet, generate_mnemonic
-from ..key import Key
-from ..managers.device_manager import get_device_class
-from ..devices.bitcoin_core import BitcoinCore
-from ..managers.wallet_manager import purposes
-from ..specter_error import handle_exception
+from flask import render_template, request
+from flask_babel import lazy_gettext as _
+from flask_login import login_required
+
+from ..helpers import alias
 from ..util.bitcoind_setup_tasks import (
-    setup_bitcoind_thread,
     setup_bitcoind_directory_thread,
+    setup_bitcoind_thread,
 )
-from ..util.tor_setup_tasks import (
-    setup_tor_thread,
-)
+from ..util.tor_setup_tasks import setup_tor_thread
+
+logger = logging.getLogger(__name__)
 
 rand = random.randint(0, 1e32)  # to force style refresh
 
@@ -117,13 +113,26 @@ def setup_tor():
         not os.path.isfile(app.specter.torbrowser_path)
         and app.specter.setup_status["torbrowser"]["stage_progress"] == -1
     ):
+        # There is no Tor Browser binary for Raspberry Pi 4 (armv7l)
+        if platform.system() == "Linux" and "armv" in platform.machine():
+            return {
+                "error": _(
+                    "Linux ARM devices (e.g. Raspberry Pi) must manually install Tor"
+                )
+            }
+        if not (getattr(sys, "frozen", False) and hasattr(sys, "_MEIPASS")):
+            return {
+                "error": _(
+                    "Sorry, Internal Tor Setup is not possible with Pip-installations."
+                )
+            }
         t = threading.Thread(target=setup_tor_thread, args=(app.specter,))
         t.start()
     elif os.path.isfile(app.specter.torbrowser_path):
-        return {"error": "Tor is already installed"}
+        return {"error": _("Tor is already installed")}
     elif app.specter.setup_status["torbrowser"]["stage_progress"] != -1:
-        return {"error": "Tor installation is still under progress"}
-    return {"success": "Starting Tor setup!"}
+        return {"error": _("Tor installation is still in progress")}
+    return {"success": _("Starting Tor setup!")}
 
 
 @setup_endpoint.route("/setup_bitcoind", methods=["POST"])
@@ -140,10 +149,10 @@ def setup_bitcoind():
         )
         t.start()
     elif os.path.isfile(app.specter.bitcoind_path):
-        return {"error": "Bitcoin Core is already installed"}
+        return {"error": _("Bitcoin Core is already installed")}
     elif app.specter.setup_status["bitcoind"]["stage_progress"] != -1:
-        return {"error": "Bitcoin Core installation is still under progress"}
-    return {"success": "Starting Bitcoin Core setup!"}
+        return {"error": _("Bitcoin Core installation is still in progress")}
+    return {"success": _("Starting Bitcoin Core setup!")}
 
 
 @setup_endpoint.route("/setup_bitcoind_datadir", methods=["POST"])
@@ -159,28 +168,20 @@ def setup_bitcoind_datadir():
             if network == "main"
             else f"Specter {network.title()} {i}"
         )
-    print(
-        os.path.join(
-            app.specter.node_manager.data_folder,
-            f"{alias(node_name)}/.bitcoin-{network}",
-        )
-    )
     node_default_datadir = os.path.join(
         app.specter.node_manager.data_folder, f"{alias(node_name)}/.bitcoin-{network}"
     )
-    if os.path.exists(
-        request.form.get("bitcoin_core_datadir", None)
-        if request.form.get("bitcoin_core_datadir", None)
-        else node_default_datadir
-    ):
+    user_selected_datadir = request.form.get(
+        "bitcoin_core_datadir", node_default_datadir
+    )
+    if os.path.exists(user_selected_datadir):
         if request.form["override_data_folder"] != "true":
+            logger.warning(
+                f"Bitcoin Core data directory at {user_selected_datadir} already exists and no orride permission was explicitly given."
+            )
             return {"error": "data folder already exists"}
-        shutil.rmtree(
-            request.form.get("bitcoin_core_datadir", None)
-            if request.form.get("bitcoin_core_datadir", None)
-            else node_default_datadir,
-            ignore_errors=True,
-        )
+        logger.info(f"Deleting Bitcoin Core data directory at: {user_selected_datadir}")
+        shutil.rmtree(user_selected_datadir, ignore_errors=True)
     if (
         os.path.isfile(app.specter.bitcoind_path)
         and app.specter.setup_status["bitcoind"]["stage_progress"] == -1
@@ -188,11 +189,8 @@ def setup_bitcoind_datadir():
         node = app.specter.node_manager.add_internal_node(
             node_name,
             network=network,
+            datadir=user_selected_datadir,
         )
-        if request.form.get("bitcoin_core_datadir", None):
-            node.update_rpc(
-                datadir=request.form.get("bitcoin_core_datadir", node.datadir),
-            )
         app.specter.update_setup_status("bitcoind", "STARTING_SETUP")
         quicksync = request.form["quicksync"] == "true"
         pruned = request.form["nodetype"] == "pruned"
@@ -202,10 +200,10 @@ def setup_bitcoind_datadir():
         )
         t.start()
     elif not os.path.isfile(app.specter.bitcoind_path):
-        return {"error": "Bitcoin Core in not installed but required for this step"}
+        return {"error": _("Bitcoin Core in not installed but required for this step")}
     elif app.specter.setup_status["bitcoind"]["stage_progress"] != -1:
-        return {"error": "Bitcoin Core installation is still under progress"}
-    return {"success": "Starting Bitcoin Core setup!"}
+        return {"error": _("Bitcoin Core installation is still in progress")}
+    return {"success": _("Starting Bitcoin Core setup!")}
 
 
 ######################### Setup status (open endpoint) #######################################
