@@ -463,7 +463,8 @@ class Wallet:
                     for address in [
                         tx["details"][0].get("address")
                         for tx in txs.values()
-                        if tx.get("details")
+                        if tx
+                        and tx.get("details")
                         and (
                             tx.get("details")[0].get("category") != "send"
                             and tx["details"][0].get("address") not in self._addresses
